@@ -31,13 +31,17 @@ class Benchmark(APIResource):
     def from_get(cls, response):
         return cls.from_response(response.json())
 
+    def refresh(self):
+        benchmark = self.get(self.benchmark_uuid)
+        self.__dict__.update(benchmark.__dict__)
+
     @classmethod
     def list(cls, ensemble):
         parent_endpoint = f"{hypervector.API_BASE}/definition/{ensemble.definition_uuid}" \
                           f"/ensemble/{ensemble.ensemble_uuid}"
         endpoint = f"{parent_endpoint}/benchmarks"
-        response = requests.get(endpoint, headers=cls.get_headers())
-        return [cls.from_response(obj) for obj in response.json()]
+        response = cls.request(endpoint)
+        return [cls.from_response(obj) for obj in response]
 
     @classmethod
     def new(cls, ensemble, expected_output):
